/* genericstub -- generic stub file to use for mingw packages
   will respond to --help and --version, exits with 0

   Copyright (C) 89, 90, 91, 95, 96, 97, 98, 99, 2000 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Adapted from other utils by Bruce E. Wampler 2/19/2000 */

#include <config.h>
#include <stdio.h>
#include <getopt.h>

#ifndef STUB_NAME
#define STUB_NAME "stub"
#endif

/* The name the program was run with. */
#ifndef PROGRAM_NAME
#define PROGRAM_NAME(x) x
#endif
char *program_name;

/* If nonzero, display usage information and exit.  */
static int show_help;

/* If nonzero, print the version on standard output and exit.  */
static int show_version;

static struct option const long_options[] =
{
  {"help", no_argument, &show_help, 1},
  {"version", no_argument, &show_version, 1},
  {0, 0, 0, 0}
};

static void
usage (int status)
{
  if (status != 0)
    fprintf (stderr, "Try `%s --help' for more information.\n",
	     program_name);
  else
    {
      printf ("Usage: %s [OPTION]... FILE...\n",program_name);
      printf (" \n\
      --help              display this help and exit\n\
      --version           output version information and exit\n\
\n\
NOTE: This program is non-functional on Windows. It simply returns\n\
an exit code of 0 to work in scripts.\n");
      close_stdout ();
    }
  exit (status);
}

/* Parse the ASCII mode given on the command line into a linked list
   of `struct mode_change' and apply that to each file argument. */

int
main (int argc, char **argv)
{
  int c;
  program_name = PROGRAM_NAME(argv[0]);

  while (1)
    {

      c = getopt_long (argc, argv, "", long_options, NULL);
      if (c == -1)
	break;
      /* don't usage - just assume valid switches */
    }

  if (show_version)
    {
      printf ("%s (%s) %s\n", STUB_NAME, GNU_PACKAGE, VERSION);
      close_stdout ();
      exit (0);
    }

  if (show_help)
    usage (0);

  exit (0);
}
